@@ -8,6 +8,6 @@
 // compile typescript on the fly
 // eslint-disable-next-line import/no-extraneous-dependencies
 
-require('@kbn/optimizer').registerNodeAutoTranspilation();
+require('@kbn/babel-register').registerNodeAutoTranspilation();
 
 require('./create-functional-tests-archive/index.ts');
\ No newline at end of file
